@@ -4,7 +4,8 @@ This module adds capabilities to argparse by patching a few of its functions. It
 class called Cmd2ArgumentParser which improves error and help output over normal argparse. All cmd2 code uses
 this parser and it is recommended that developers of cmd2-based apps either use it or write their own parser
 that inherits from it. This will give a consistent look-and-feel between the help/error output of built-in
-cmd2 commands and the app-specific commands.
+cmd2 commands and the app-specific commands. If you wish to override the parser used by cmd2's built-in
+commands, see override_parser.py example.
 
 Since the new capabilities are added by patching at the argparse API level, they are available whether or not
 Cmd2ArgumentParser is used. However, the help and error output of Cmd2ArgumentParser is customized to notate
@@ -182,7 +183,7 @@ import re
 import sys
 # noinspection PyUnresolvedReferences,PyProtectedMember
 from argparse import ZERO_OR_MORE, ONE_OR_MORE, ArgumentError, _
-from typing import Callable, Optional, Tuple, Union
+from typing import Callable, Optional, Tuple, Type, Union
 
 from .ansi import ansi_aware_write, style_error
 
@@ -806,3 +807,13 @@ class Cmd2ArgumentParser(argparse.ArgumentParser):
             if file is None:
                 file = sys.stderr
             ansi_aware_write(file, message)
+
+
+# The default ArgumentParser class for a cmd2 app
+DEFAULT_ARGUMENT_PARSER = Cmd2ArgumentParser
+
+
+def set_default_argument_parser(parser: Type[argparse.ArgumentParser]) -> None:
+    """Set the default ArgumentParser class for a cmd2 app"""
+    global DEFAULT_ARGUMENT_PARSER
+    DEFAULT_ARGUMENT_PARSER = parser
